@@ -111,6 +111,8 @@ class R3sponse(object):
 		# the response dict (leave message None to use).
 		response={},
 		# optionals:
+		# the log level for printing to console.
+		log_level=0,
 		# save to log file.
 		save=False,
 		# save errors only (for option 2 only).
@@ -127,7 +129,8 @@ class R3sponse(object):
 				msg = response["message"]
 		else: 
 			msg = message
-		print(color.fill(msg))
+		if log_level >= self.log_level:
+			print(color.fill(msg))
 		if save: 
 			self.__log_to_file__(msg)
 		elif save_errors and _error_:
